@@ -4,12 +4,16 @@ class MwClientError(RuntimeError):
 class MediaWikiVersionError(MwClientError):
 	pass
 
-	
+class APIDisabledError(MwClientError):
+	pass
+
 class HTTPError(MwClientError):
 	pass
 class HTTPStatusError(MwClientError):
 	pass
-	
+class HTTPRedirectError(HTTPError):
+	pass
+
 class MaximumRetriesExceeded(MwClientError):
 	pass
 	
