@@ -56,11 +56,12 @@
 #include <QtGui/QHeaderView>
 #include <QtGui/QMenu>
 #include <QtGui/QStackedWidget>
+#include <QScrollArea>
 
 using namespace Editor;
 
 EditorWindow::EditorWindow(ParleyMainWindow* parent)
-    :KXmlGuiWindow(parent), m_mainWindow(parent)
+    : KXmlGuiWindow(parent), m_mainWindow(parent)
 {
     // KXmlGui
     setXMLFile("editorui.rc");
@@ -80,12 +81,14 @@ EditorWindow::EditorWindow(ParleyMainWindow* parent)
     KConfigGroup cfg(KSharedConfig::openConfig("parleyrc"), objectName());
     applyMainWindowSettings(cfg);
 
-    connect(parent->parleyDocument(), SIGNAL(documentChanged(KEduVocDocument*)), this, SLOT(updateDocument(KEduVocDocument*)));
-    connect(parent->parleyDocument(), SIGNAL(languagesChanged()), this, SLOT(slotLanguagesChanged()));
+    connect(parent->parleyDocument(), SIGNAL(documentChanged(KEduVocDocument*)),
+            this,                     SLOT(updateDocument(KEduVocDocument*)));
+    connect(parent->parleyDocument(), SIGNAL(languagesChanged()),
+            this,                     SLOT(slotLanguagesChanged()));
     connect(parent->parleyDocument(), SIGNAL(statesNeedSaving()), this, SLOT(saveState()));
     connect(parent, SIGNAL(preferencesChanged()), this, SLOT(applyPrefs()));
 
-    QTimer::singleShot( 0, this, SLOT(initScripts()) );
+    QTimer::singleShot(0, this, SLOT(initScripts()));
 }
 
 EditorWindow::~EditorWindow()
@@ -107,6 +110,7 @@ void EditorWindow::updateDocument(KEduVocDocument *doc)
     m_summaryWordWidget->slotDocumentChanged(doc);
     m_inflectionWidget->setDocument(doc);
     m_comparisonWidget->setDocument(doc);
+    m_synonymWidget->setDocument(doc);
 
     if (!m_mainWindow->parleyDocument()->document()) {
         return;
@@ -120,13 +124,14 @@ void EditorWindow::updateDocument(KEduVocDocument *doc)
     m_lessonView->expandToDepth(0);
     m_wordTypeView->expandToDepth(0);
 
-    connect(m_mainWindow->parleyDocument()->document(), SIGNAL(docModified(bool)), m_mainWindow, SLOT(slotUpdateWindowCaption()));
+    connect(m_mainWindow->parleyDocument()->document(), SIGNAL(docModified(bool)),
+            m_mainWindow,                               SLOT(slotUpdateWindowCaption()));
 
     connect(m_vocabularyView->selectionModel(),
-                SIGNAL(selectionChanged(const QItemSelection &, const QItemSelection &)),
+            SIGNAL(selectionChanged(const QItemSelection &, const QItemSelection &)),
             m_summaryWordWidget, SLOT(slotSelectionChanged(const QItemSelection &, const QItemSelection &)));
     connect(m_vocabularyView->selectionModel(),
-                SIGNAL(selectionChanged(const QItemSelection &, const QItemSelection &)),
+            SIGNAL(selectionChanged(const QItemSelection &, const QItemSelection &)),
             m_latexWidget, SLOT(slotSelectionChanged(const QItemSelection &, const QItemSelection &)));
 
     setCaption(doc->url().fileName(), false);
@@ -134,7 +139,7 @@ void EditorWindow::updateDocument(KEduVocDocument *doc)
     m_mainWindow->slotUpdateWindowCaption();
 
     m_spellCheckMenu->menu()->clear();
-    for(int i = 0; i < doc->identifierCount(); ++i) {
+    for (int i = 0; i < doc->identifierCount(); ++i) {
         KAction* languageSpellCheck = new KAction(doc->identifier(i).name(), m_spellCheckMenu->menu());
         m_spellCheckMenu->menu()->addAction(languageSpellCheck);
         m_spellCheckMapper->setMapping(languageSpellCheck, i);
@@ -157,25 +162,25 @@ void EditorWindow::initDockWidgets()
     m_lessonModel = new LessonModel(this);
     m_lessonView->setModel(m_lessonModel);
     m_lessonView->setToolTip(i18n("Right click to add, delete, or rename lessons. \n"
-            "With the checkboxes you can select which lessons you want to practice. \n"
-            "Only checked lessons [x] will be asked in the tests!"));
+                                  "With the checkboxes you can select which lessons you want to practice. \n"
+                                  "Only checked lessons [x] will be asked in the tests!"));
 
     connect(m_lessonView, SIGNAL(selectedLessonChanged(KEduVocLesson*)),
-        m_vocabularyModel, SLOT(setLesson(KEduVocLesson*)));
+            m_vocabularyModel, SLOT(setLesson(KEduVocLesson*)));
 
     connect(m_lessonView, SIGNAL(signalShowContainer(KEduVocContainer*)),
-        m_vocabularyModel, SLOT(showContainer(KEduVocContainer*)));
+            m_vocabularyModel, SLOT(showContainer(KEduVocContainer*)));
 
     connect(m_vocabularyView, SIGNAL(translationChanged(KEduVocExpression*, int)),
-        m_lessonView, SLOT(setTranslation(KEduVocExpression*, int)));
+            m_lessonView, SLOT(setTranslation(KEduVocExpression*, int)));
 
 
 // Word types dock
     QDockWidget* wordTypeDockWidget = new QDockWidget(i18n("Word Types"), this);
-    wordTypeDockWidget->setObjectName( "WordTypeDock" );
+    wordTypeDockWidget->setObjectName("WordTypeDock");
     m_wordTypeView = new WordTypeView(this);
     wordTypeDockWidget->setWidget(m_wordTypeView);
-    addDockWidget( Qt::LeftDockWidgetArea, wordTypeDockWidget );
+    addDockWidget(Qt::LeftDockWidgetArea, wordTypeDockWidget);
     m_dockWidgets.append(wordTypeDockWidget);
 
     m_wordTypeModel = new WordTypeModel(this);
@@ -189,13 +194,16 @@ void EditorWindow::initDockWidgets()
     m_wordTypeView->setModel(m_wordTypeModel);
 
     connect(m_vocabularyView, SIGNAL(translationChanged(KEduVocExpression*, int)),
-        m_wordTypeView, SLOT(setTranslation(KEduVocExpression*, int)));
+            m_wordTypeView, SLOT(setTranslation(KEduVocExpression*, int)));
 
 // Inflections
     QDockWidget *inflectionDock = new QDockWidget(i18n("Inflection (verbs, adjectives, nouns)"), this);
     inflectionDock->setObjectName("InflectionDock");
     m_inflectionWidget = new InflectionWidget(this);
-    inflectionDock->setWidget(m_inflectionWidget);
+    QScrollArea *inflectionScrollArea = new QScrollArea(this);
+    inflectionScrollArea->setWidgetResizable(true);
+    inflectionScrollArea->setWidget(m_inflectionWidget);
+    inflectionDock->setWidget(inflectionScrollArea);
     addDockWidget(Qt::RightDockWidgetArea, inflectionDock);
     m_dockWidgets.append(inflectionDock);
     actionCollection()->addAction("show_inflection_dock", inflectionDock->toggleViewAction());
@@ -208,66 +216,87 @@ void EditorWindow::initDockWidgets()
     QDockWidget *comparisonDock = new QDockWidget(i18n("Comparison forms"), this);
     comparisonDock->setObjectName("ComparisonDock");
     m_comparisonWidget = new ComparisonWidget(this);
-    comparisonDock->setWidget(m_comparisonWidget);
+    QScrollArea *comparisonScrollArea = new QScrollArea(this);
+    comparisonScrollArea->setWidgetResizable(true);
+    comparisonScrollArea->setWidget(m_comparisonWidget);
+    inflectionDock->setWidget(comparisonScrollArea);
     addDockWidget(Qt::RightDockWidgetArea, comparisonDock);
     m_dockWidgets.append(comparisonDock);
     actionCollection()->addAction("show_comparison_dock", comparisonDock->toggleViewAction());
     comparisonDock->setVisible(false);
     connect(m_vocabularyView, SIGNAL(translationChanged(KEduVocExpression*, int)),
-        m_comparisonWidget, SLOT(setTranslation(KEduVocExpression*, int)));
+            m_comparisonWidget, SLOT(setTranslation(KEduVocExpression*, int)));
+    tabifyDockWidget(comparisonDock,inflectionDock);
 
 // Multiple choice
     QDockWidget *multipleChoiceDock = new QDockWidget(i18n("Multiple Choice"), this);
     multipleChoiceDock->setObjectName("MultipleChoiceDock");
     MultipleChoiceWidget *multipleChoiceWidget = new MultipleChoiceWidget(this);
-    multipleChoiceDock->setWidget(multipleChoiceWidget);
+    QScrollArea *multipleChoiceScrollArea = new QScrollArea(this);
+    multipleChoiceScrollArea->setWidgetResizable(true);
+    multipleChoiceScrollArea->setWidget(multipleChoiceWidget);
+    multipleChoiceDock->setWidget(multipleChoiceScrollArea);
     addDockWidget(Qt::RightDockWidgetArea, multipleChoiceDock);
     m_dockWidgets.append(multipleChoiceDock);
     actionCollection()->addAction("show_multiplechoice_dock", multipleChoiceDock->toggleViewAction());
     multipleChoiceDock->setVisible(false);
     connect(m_vocabularyView, SIGNAL(translationChanged(KEduVocExpression*, int)),
-        multipleChoiceWidget, SLOT(setTranslation(KEduVocExpression*, int)));
+            multipleChoiceWidget, SLOT(setTranslation(KEduVocExpression*, int)));
 
 // Synonym (and the same for antonym and false friends)
     QDockWidget *synonymDock = new QDockWidget(i18n("Synonyms"), this);
     synonymDock->setObjectName("SynonymDock");
-    SynonymWidget *synonymWidget = new SynonymWidget(SynonymWidget::Synonym, this);
-    synonymDock->setWidget(synonymWidget);
+    m_synonymWidget = new SynonymWidget(SynonymWidget::Synonym, this);
+    QScrollArea *synonymScrollArea = new QScrollArea(this);
+    synonymScrollArea->setWidgetResizable(true);
+    synonymScrollArea->setWidget(m_synonymWidget);
+    synonymDock->setWidget(synonymScrollArea);
     addDockWidget(Qt::RightDockWidgetArea, synonymDock);
     m_dockWidgets.append(synonymDock);
     actionCollection()->addAction("show_synonym_dock", synonymDock->toggleViewAction());
     synonymDock->setVisible(false);
     connect(m_vocabularyView, SIGNAL(translationChanged(KEduVocExpression*, int)),
-            synonymWidget, SLOT(setTranslation(KEduVocExpression*, int)));
+            m_synonymWidget, SLOT(setTranslation(KEduVocExpression*, int)));
 
     QDockWidget *antonymDock = new QDockWidget(i18n("Antonyms"), this);
     antonymDock->setObjectName("AntonymDock");
     SynonymWidget *antonymWidget = new SynonymWidget(SynonymWidget::Antonym, this);
-    antonymDock->setWidget(antonymWidget);
+    QScrollArea *antonymScrollArea = new QScrollArea(this);
+    antonymScrollArea->setWidgetResizable(true);
+    antonymScrollArea->setWidget(antonymWidget);
+    antonymDock->setWidget(antonymScrollArea);
     addDockWidget(Qt::RightDockWidgetArea, antonymDock);
     m_dockWidgets.append(antonymDock);
     actionCollection()->addAction("show_antonym_dock", antonymDock->toggleViewAction());
     antonymDock->setVisible(false);
     connect(m_vocabularyView, SIGNAL(translationChanged(KEduVocExpression*, int)),
             antonymWidget, SLOT(setTranslation(KEduVocExpression*, int)));
+    tabifyDockWidget(synonymDock,antonymDock);
 
     QDockWidget *falseFriendDock = new QDockWidget(i18n("False Friends"), this);
     falseFriendDock->setObjectName("FalseFriendDock");
     SynonymWidget *falseFriendWidget = new SynonymWidget(SynonymWidget::FalseFriend, this);
-    falseFriendDock->setWidget(falseFriendWidget);
+    QScrollArea *falseFriendScrollArea = new QScrollArea(this);
+    falseFriendScrollArea->setWidgetResizable(true);
+    falseFriendScrollArea->setWidget(falseFriendWidget);
+    falseFriendDock->setWidget(falseFriendScrollArea);
     addDockWidget(Qt::RightDockWidgetArea, falseFriendDock);
     m_dockWidgets.append(falseFriendDock);
     actionCollection()->addAction("show_falsefriend_dock", falseFriendDock->toggleViewAction());
     falseFriendDock->setVisible(false);
     connect(m_vocabularyView, SIGNAL(translationChanged(KEduVocExpression*, int)),
             falseFriendWidget, SLOT(setTranslation(KEduVocExpression*, int)));
+    tabifyDockWidget(antonymDock,falseFriendDock);
 
 // Pronunciation symbols - Use KCharSelect
     QDockWidget *charSelectDock = new QDockWidget(i18n("Phonetic Symbols"), this);
     charSelectDock->setObjectName("IPADock");
     KCharSelect *charSelectWidget = new KCharSelect(this, 0, KCharSelect::SearchLine | KCharSelect::BlockCombos | KCharSelect::CharacterTable);
     charSelectWidget->setCurrentChar(0x0250);
-    charSelectDock->setWidget(charSelectWidget);
+    QScrollArea *charSelectScrollArea = new QScrollArea(this);
+    charSelectScrollArea->setWidgetResizable(true);
+    charSelectScrollArea->setWidget(charSelectWidget);
+    charSelectDock->setWidget(charSelectScrollArea);
     addDockWidget(Qt::BottomDockWidgetArea, charSelectDock);
     m_dockWidgets.append(charSelectDock);
     actionCollection()->addAction("show_pronunciation_dock", charSelectDock->toggleViewAction());
@@ -278,20 +307,27 @@ void EditorWindow::initDockWidgets()
     QDockWidget *imageDock = new QDockWidget(i18n("Image"), this);
     imageDock->setObjectName("ImageDock");
     ImageChooserWidget *imageChooserWidget = new ImageChooserWidget(this);
-    imageDock->setWidget(imageChooserWidget);
+    QScrollArea *imageScrollArea = new QScrollArea(this);
+    imageScrollArea->setWidgetResizable(true);
+    imageScrollArea->setWidget(imageChooserWidget);
+    imageDock->setWidget(imageScrollArea);
     addDockWidget(Qt::RightDockWidgetArea, imageDock);
     m_dockWidgets.append(imageDock);
     actionCollection()->addAction("show_image_dock", imageDock->toggleViewAction());
     imageDock->setVisible(false);
     connect(m_vocabularyView, SIGNAL(translationChanged(KEduVocExpression*, int)),
-        imageChooserWidget, SLOT(setTranslation(KEduVocExpression*, int)));
+            imageChooserWidget, SLOT(setTranslation(KEduVocExpression*, int)));
+    tabifyDockWidget(multipleChoiceDock,imageDock);
 
 // Summary word
     QDockWidget *summaryDock = new QDockWidget(i18n("Summary"), this);
     summaryDock->setObjectName("SummaryDock");
     m_summaryWordWidget = new SummaryWordWidget(m_vocabularyFilter, m_mainWindow->parleyDocument()->document(), this);
-    summaryDock->setWidget(m_summaryWordWidget);
-    addDockWidget(Qt::RightDockWidgetArea, summaryDock);
+    QScrollArea *summaryScrollArea = new QScrollArea(this);
+    summaryScrollArea->setWidgetResizable(true);
+    summaryScrollArea->setWidget(m_summaryWordWidget);
+    summaryDock->setWidget(summaryScrollArea);
+    addDockWidget(Qt::BottomDockWidgetArea, summaryDock);
     actionCollection()->addAction("show_summary_dock", summaryDock->toggleViewAction());
     summaryDock->setVisible(false);
     m_dockWidgets.append(summaryDock);
@@ -302,38 +338,50 @@ void EditorWindow::initDockWidgets()
     QDockWidget *audioDock = new QDockWidget(i18n("Sound"), this);
     audioDock->setObjectName("AudioDock");
     AudioWidget *audioWidget = new AudioWidget(this);
-    audioDock->setWidget(audioWidget);
+    QScrollArea *audioScrollArea = new QScrollArea(this);
+    audioScrollArea->setWidgetResizable(true);
+    audioScrollArea->setWidget(audioWidget);
+    audioDock->setWidget(audioScrollArea);
     addDockWidget(Qt::RightDockWidgetArea, audioDock);
     m_dockWidgets.append(audioDock);
     actionCollection()->addAction("show_audio_dock", audioDock->toggleViewAction());
     audioDock->setVisible(false);
     connect(m_vocabularyView, SIGNAL(translationChanged(KEduVocExpression*, int)),
-        audioWidget, SLOT(setTranslation(KEduVocExpression*, int)));
+            audioWidget, SLOT(setTranslation(KEduVocExpression*, int)));
+    tabifyDockWidget(imageDock,audioDock);
 
 // browser
     QDockWidget *browserDock = new QDockWidget(i18n("Internet"), this);
     browserDock->setObjectName("BrowserDock");
     //TinyWebBrowser *browserWidget = new TinyWebBrowser(this);
     BrowserWidget *htmlPart = new BrowserWidget(browserDock);
-    browserDock->setWidget(htmlPart);
-    addDockWidget(Qt::RightDockWidgetArea, browserDock);
+    QScrollArea *browserScrollArea = new QScrollArea(this);
+    browserScrollArea->setWidgetResizable(true);
+    browserScrollArea->setWidget(htmlPart);
+    browserDock->setWidget(browserScrollArea);
+    addDockWidget(Qt::BottomDockWidgetArea, browserDock);
     m_dockWidgets.append(browserDock);
     actionCollection()->addAction("show_browser_dock", browserDock->toggleViewAction());
     browserDock->setVisible(false);
     connect(m_vocabularyView, SIGNAL(translationChanged(KEduVocExpression*, int)),
             htmlPart, SLOT(setTranslation(KEduVocExpression*, int)));
+    tabifyDockWidget(summaryDock,browserDock);
 
 // LaTeX
     QDockWidget *latexDock = new QDockWidget(i18n("LaTeX"), this);
     latexDock->setObjectName("LatexDock");
     m_latexWidget = new LatexWidget(m_vocabularyFilter, m_mainWindow->parleyDocument()->document(), this);
-    latexDock->setWidget(m_latexWidget);
+    QScrollArea *latexScrollArea = new QScrollArea(this);
+    latexScrollArea->setWidgetResizable(true);
+    latexScrollArea->setWidget(m_latexWidget);
+    latexDock->setWidget(latexScrollArea);
     addDockWidget(Qt::RightDockWidgetArea, latexDock);
     actionCollection()->addAction("show_latex_dock", latexDock->toggleViewAction());
     latexDock->setVisible(false);
     m_dockWidgets.append(latexDock);
     connect(m_vocabularyView, SIGNAL(translationChanged(KEduVocExpression*, int)),
             m_latexWidget, SLOT(setTranslation(KEduVocExpression*, int)));
+    tabifyDockWidget(audioDock,latexDock);
 
 // Grades
 //     QDockWidget *gradeDock = new QDockWidget(i18n("Grade"), this);
@@ -352,7 +400,7 @@ void EditorWindow::initActions()
     m_spellCheckMenu->setMenu(new QMenu(this));
     m_spellCheckMapper = new QSignalMapper(this);
     connect(m_spellCheckMapper, SIGNAL(mapped(int)), m_vocabularyView, SLOT(checkSpelling(int)));
-    
+
     ParleyActions::create(ParleyActions::ToggleShowSublessons, m_vocabularyModel, SLOT(showEntriesOfSubcontainers(bool)), actionCollection());
     ParleyActions::create(ParleyActions::AutomaticTranslation, m_vocabularyModel, SLOT(automaticTranslation(bool)), actionCollection());
     ParleyActions::create(ParleyActions::StartPractice, m_mainWindow, SLOT(showPracticeConfiguration()), actionCollection());
@@ -433,7 +481,8 @@ void EditorWindow::startSearch()
     m_searchLine->setFocus();
 }
 
-void EditorWindow::slotShowScriptManager() {
+void EditorWindow::slotShowScriptManager()
+{
     ScriptDialog * dialog = new ScriptDialog(m_scriptManager);
     dialog->show();
 }
