@@ -14,6 +14,7 @@
 #include "multiplechoicemodewidget.h"
 #include "multiplechoicedata.h"
 #include "latexrenderer.h"
+#include "guifrontend.h"
 
 #include "ui_practice_widget_multiplechoice.h"
 
@@ -22,31 +23,34 @@
 #include <QtGui/QRadioButton>
 #include <QTimer>
 #include <QKeyEvent>
+#include <QVBoxLayout>
 
 using namespace Practice;
 
 
-MultiplechoiceModeWidget::MultiplechoiceModeWidget (GuiFrontend *frontend, QWidget* parent )
-    : AbstractModeWidget (frontend, parent), m_latexRenderer(0)
+MultiplechoiceModeWidget::MultiplechoiceModeWidget(GuiFrontend *frontend, QWidget* parent)
+    : AbstractModeWidget(frontend, parent), m_latexRenderer(0)
 {
     m_ui = new Ui::MultiplechoicePracticeWidget();
     m_ui->setupUi(this);
 
     for (int i = 0; i < 5; i++) {
         QAction *action = new QAction(this);
-        action->setShortcut(Qt::Key_1+i);
+        action->setShortcut(Qt::Key_1 + i);
         addAction(action);
         m_actions.append(action);
     }
+    connect(frontend, SIGNAL(continueAction()), this, SIGNAL(stopAudio()));
+    connect(frontend, SIGNAL(skipAction()), this, SIGNAL(stopAudio()));
 
 }
 
-void MultiplechoiceModeWidget::setQuestionFont ( const QFont& font )
+void MultiplechoiceModeWidget::setQuestionFont(const QFont& font)
 {
     m_ui->questionLabel->setFont(font);
 }
 
-void MultiplechoiceModeWidget::setSolutionFont ( const QFont& font )
+void MultiplechoiceModeWidget::setSolutionFont(const QFont& font)
 {
     m_solutionFont = font;
 }
@@ -61,7 +65,7 @@ void MultiplechoiceModeWidget::setQuestion(const QVariant& question)
 
     m_ui->questionLabel->setMinimumSize(QSize(0, 0));
     if (LatexRenderer::isLatex(data.question)) {
-        if(!m_latexRenderer) {
+        if (!m_latexRenderer) {
             m_latexRenderer = new LatexRenderer(this);
             m_latexRenderer->setResultLabel(m_ui->questionLabel);
         }
@@ -70,14 +74,14 @@ void MultiplechoiceModeWidget::setQuestion(const QVariant& question)
         m_ui->questionLabel->setText(data.question);
     }
 
-    if (m_choiceButtons.size() != data.choices.size()){
+    if (m_choiceButtons.size() != data.choices.size()) {
         qDeleteAll(m_choiceButtons);
         m_choiceButtons.clear();
         setNumberOfRadioButtons(data.choices.size());
     }
 
     int j = 0;
-    foreach(QRadioButton *radio,m_choiceButtons){
+    foreach(QRadioButton * radio, m_choiceButtons) {
         radio->setText(data.choices[j]);
         radio->setToolTip(data.choices[j]);
         radio->setFont(m_solutionFont);
@@ -93,9 +97,13 @@ void MultiplechoiceModeWidget::showQuestion()
     m_choiceButtons[0]->setChecked(false);
     m_choiceButtons[0]->setAutoExclusive(true);
 
+    m_ui->questionPronunciationLabel->setVisible(m_ui->questionPronunciationLabel->isEnabled());
+    m_ui->questionSoundButton->setVisible(true); // TODO: Use Configuration's Sound Enable QCheckbox
+    m_ui->solutionPronunciationLabel->setVisible(false);
+    m_ui->solutionSoundButton->setVisible(false);
     m_ui->feedbackLabel->clear();
 
-    foreach(QRadioButton *radio, m_choiceButtons) {
+    foreach(QRadioButton * radio, m_choiceButtons) {
         radio->setPalette(palette());
         radio->setEnabled(true);
     }
@@ -105,9 +113,12 @@ void MultiplechoiceModeWidget::showQuestion()
 
 void MultiplechoiceModeWidget::setNumberOfRadioButtons(const int numberOfChoices)
 {
-    for (int i=0;i<numberOfChoices;i++){
+    QVBoxLayout *verticalLayout = new QVBoxLayout();
+    m_ui->gridLayout->addLayout(verticalLayout, 2, 0);
+
+    for (int i = 0; i < numberOfChoices; i++) {
         QRadioButton *radio_button = new QRadioButton(this);
-        m_ui->verticalLayout->insertWidget(m_ui->verticalLayout->count()-1, radio_button);
+        verticalLayout->addWidget(radio_button);
         m_choiceButtons.append(radio_button);
         if (i < 5) {
             connect(m_actions.at(i), SIGNAL(triggered()), radio_button, SLOT(click()));
@@ -117,15 +128,15 @@ void MultiplechoiceModeWidget::setNumberOfRadioButtons(const int numberOfChoices
     }
 }
 
-void MultiplechoiceModeWidget::setSynonym(const QString& entry)
+void MultiplechoiceModeWidget::setSynonym(const QString& /*entry*/)
 {
-  //TODO Do something here to show synonyms
+    //TODO Do something here to show synonyms
 }
 
 
 void MultiplechoiceModeWidget::showSynonym()
 {
-  //TODO Do something here to show synonyms
+    //TODO Do something here to show synonyms
 }
 
 bool MultiplechoiceModeWidget::eventFilter(QObject *obj, QEvent *event)
@@ -170,16 +181,18 @@ void MultiplechoiceModeWidget::showSolution()
     if (input != -1 && input != m_solution) {
         m_choiceButtons[input]->setPalette(m_wrongPalette);
     }
-    foreach(QRadioButton *radio, m_choiceButtons) {
+    foreach(QRadioButton * radio, m_choiceButtons) {
         radio->setEnabled(false);
     }
+    m_ui->solutionPronunciationLabel->setVisible(m_ui->solutionPronunciationLabel->isEnabled());
+    m_ui->solutionSoundButton->setVisible(true); // TODO: Use Configuration's Sound Enable QCheckbox
 }
 
 QVariant MultiplechoiceModeWidget::userInput()
 {
 
     int i = 0;
-    foreach(QRadioButton *radio,m_choiceButtons){
+    foreach(QRadioButton * radio, m_choiceButtons) {
         if (radio->isChecked()) return i;
         i++;
     }
@@ -189,22 +202,24 @@ QVariant MultiplechoiceModeWidget::userInput()
 
 void MultiplechoiceModeWidget::setQuestionSound(const KUrl& soundUrl)
 {
-
+    m_ui->questionSoundButton->setSoundFile(soundUrl);
 }
 
 void MultiplechoiceModeWidget::setSolutionSound(const KUrl& soundUrl)
 {
-
+    m_ui->solutionSoundButton->setSoundFile(soundUrl);
 }
 
 void MultiplechoiceModeWidget::setSolutionPronunciation(const QString& pronunciationText)
 {
-
+    m_ui->solutionPronunciationLabel->setText('[' + pronunciationText + ']');
+    m_ui->solutionPronunciationLabel->setEnabled(!pronunciationText.isNull());
 }
 
 void MultiplechoiceModeWidget::setQuestionPronunciation(const QString& pronunciationText)
 {
-
+    m_ui->questionPronunciationLabel->setText('[' + pronunciationText + ']');
+    m_ui->questionPronunciationLabel->setEnabled(!pronunciationText.isNull());
 }
 
 #include "multiplechoicemodewidget.moc"
